@@ -28,6 +28,8 @@
 #include <KConfigLoader>
 #include <KDeclarative/ConfigPropertyMap>
 
+#include <functional>
+
 #include "sensorfaces_export.h"
 
 class QQmlEngine;
@@ -82,7 +84,9 @@ public:
 
     QJsonArray readSensors(const KConfigGroup &config, const QString &entryName);
     QJsonArray readAndUpdateSensors(KConfigGroup &config, const QString &entryName);
-    QJsonArray resolveSensors(const QJsonArray &partialEntries);
+    QString replaceDiskId(const QString &entryname) const;
+    QString replacePartitionId(const QString &entryname) const;
+    void resolveSensors(const QJsonArray &partialEntries, std::function<void(const QJsonArray&)> callback);
     SensorFace *createGui(const QString &qmlPath);
     QQuickItem *createConfigUi(const QString &file, const QVariantMap &initialProperties);
 
@@ -118,6 +122,8 @@ public:
     PresetsModel *availablePresetsModel = nullptr;
 
     static QVector<QPair<QRegularExpression, QString>> sensorIdReplacements;
+    static QRegularExpression oldDiskSensor;
+    static QRegularExpression oldPartitionSensor;
 };
 
 }
