@@ -19,6 +19,7 @@
 
 #include "SensorQuery.h"
 
+#include <QCollator>
 #include <QDBusPendingCallWatcher>
 #include <QDBusReply>
 #include <QRegularExpression>
@@ -110,6 +111,15 @@ QStringList KSysGuard::SensorQuery::sensorIds() const
     return ids;
 }
 
+void KSysGuard::SensorQuery::sortByName()
+{
+    QCollator collator;
+    collator.setNumericMode(true);
+    std::sort(d->result.begin(), d->result.end(), [this, &collator] (const QPair<QString, SensorInfo> &left, const QPair<QString, SensorInfo> &right) {
+        return collator.compare(left.second.name, right.second.name) < 0;
+    });
+}
+
 QVector<QPair<QString, SensorInfo>> KSysGuard::SensorQuery::result() const
 {
     return d->result;
